==> pan-0.6.1.tar.gz: pan-0.6.1/pan/groups.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __GROUPS_H__
#define __GROUPS_H__

#define GROUP_ALL 0
#define GROUP_SUBSCRIBED 1
#define GROUP_NEW 2
#define GROUP_CHANGED 4
#define GROUP_ONDISK 8

typedef struct _group_data group_data;
struct _group_data
{
	gchar*  name;	     /* alt.what.is.my.name */
	gint    flags;	     /* ??? */
	GSList* articlelist; /* linked-list of all articles */
};

extern int group_mode;
extern GtkWidget *groups_clist_menu;

void grouplist_save		(void);
GtkWidget* create_articlelist_clist (void);
GtkWidget* grouplist_create (void);
void open_group_file (FILE *);
void grouplist_update	(void);
void grouplist_update_row (group_data *gdata);
void load_groups_file	(void);
void load_group_list	(void);
void grouplist_grep		(GtkWidget *);
void group_clean		(group_data *);
void grouplist_free		(GSList *);
gint compare_group_data (group_data *, group_data *);
void choose_download_dialog (group_data *);
void group_free			(group_data *gdata);
void get_all_groups		(void);
int group_get_attrib_i	(group_data *, char *);
void group_set_attrib_i	(group_data *, char *, int);
void group_add_attrib_i (group_data *, char *, int);

void unsubscribe_from_selected_cb (void);
void subscribe_to_selected_cb (void);

void download_selected_groups_cb (void);
void download_selected_groups_new_cb (void);

void grouplist_process_selcted (int type);

void grouplist_selected_download_all (void);
void grouplist_selected_download_new (void);
void grouplist_selected_subscribe (void);
void grouplist_selected_unsubscribe (void);
void grouplist_selected_empty (void);

void group_empty (group_data *gdata);
void group_empty_cb (GnomeDialog *dialog, int button_number, gpointer gdata);
void group_empty_dialog (group_data *gdata);

void click_groups_column_cb (GtkCList *clist, int n);
void add_group_to_clist (group_data *gdata);
void add_subscribed_group_to_clist (group_data* gdata);
void add_new_group_to_clist (group_data* gdata);

void group_dialog_clicked_cb (GnomeDialog* dialog, int num);
void choose_download_dialog_clicked_cb (GnomeDialog* dialog, int button_number, gpointer gdata);
void select_group_row (GtkWidget *widget, int r, int c, GdkEvent *event);
void group_props_spawn (void);
void groups_clist_button_press (GtkWidget *widget, GdkEventButton *bevent);
void group_unload (group_data *gdata);
void grouplist_process_selected (int type);
void group_save (group_data *gdata, FILE *fp);
void grouplist_load (void);

#endif /* __GROUPS_H__ */

==> pan-0.6.2.tar.gz: pan-0.6.2/pan/groups.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __GROUPS_H__
#define __GROUPS_H__

#define GROUP_ALL 0
#define GROUP_SUBSCRIBED 1
#define GROUP_NEW 2
#define GROUP_CHANGED 4
#define GROUP_ONDISK 8

typedef struct _group_data group_data;
struct _group_data
{
	gchar*  name;	     /* alt.what.is.my.name */
	gint    flags;	     /* ??? */
	GSList* articlelist; /* linked-list of all articles */
};

extern int group_mode;
extern GtkWidget *groups_clist_menu;

void grouplist_save		(GSList *);
GtkWidget* create_articlelist_clist (void);
GtkWidget* grouplist_create (void);
void open_group_file (FILE *);
void grouplist_update	(void);
void grouplist_update_row (group_data *gdata);
void load_groups_file	(void);
void load_group_list	(void);
void grouplist_grep		(GtkWidget *);
void group_clean		(group_data *);
void grouplist_free		(GSList *);
gint compare_group_data (group_data *, group_data *);
void choose_download_dialog (group_data *);
void group_free			(group_data *gdata);
void get_all_groups		(void);
int group_get_attrib_i	(group_data *, char *);
void group_set_attrib_i	(group_data *, char *, int);
void group_add_attrib_i (group_data *, char *, int);

void unsubscribe_from_selected_cb (void);
void subscribe_to_selected_cb (void);

void download_selected_groups_cb (void);
void download_selected_groups_new_cb (void);

void grouplist_process_selcted (int type);

void grouplist_selected_download_all (void);
void grouplist_selected_download_new (void);
void grouplist_selected_subscribe (void);
void grouplist_selected_unsubscribe (void);
void grouplist_selected_empty (void);

void group_empty (group_data *gdata);
void group_empty_cb (GnomeDialog *dialog, int button_number, gpointer gdata);
void group_empty_dialog (group_data *gdata);

void click_groups_column_cb (GtkCList *clist, int n);
void add_group_to_clist (group_data *gdata);
void add_subscribed_group_to_clist (group_data* gdata);
void add_new_group_to_clist (group_data* gdata);

void group_dialog_clicked_cb (GnomeDialog* dialog, int num);
void choose_download_dialog_clicked_cb (GnomeDialog* dialog, int button_number, gpointer gdata);
void grouplist_select_row (GtkWidget *widget, int r, int c, GdkEvent *event);
void group_props_spawn (void);
void groups_clist_button_press (GtkWidget *widget, GdkEventButton *bevent);
void group_unload (group_data *gdata);
void grouplist_process_selected (int type);
void group_save (group_data *gdata, FILE *fp);
void grouplist_load (void);

void group_set_attrib_char (group_data *gdata, gchar *attrib, gchar *value);
gchar* group_get_attrib_char (group_data *gdata, gchar *attrib);


#endif /* __GROUPS_H__ */
